@@ -15,7 +15,7 @@ class SessionHandler():
   def to_database(self, overwrite = False):
     session = self.create_session()
     obj = self
-    if overwrite == True: obj = self.get_or_create(session, obj)
+    if overwrite == True: obj = self.update_or_create(session, obj)
     session.add(obj)
     self.commit(session)
     return(self)
@@ -24,18 +24,20 @@ class SessionHandler():
     session = self.create_session()
     for obj in obj_list:
       if overwrite == True:
-        session = self.get_or_create(session, obj)
+        session = self.update_or_create(session, obj)
       else:
         session.add(obj)
     return self.commit(session)
   
-  def get_or_create(self,session, obj):
+  def update_or_create(self,obj):
+    session_tmp = self.create_session()
     keys = [key.name for key in inspect(obj.__class__).primary_key]
     key_values = {k: v for k, v in obj.__dict__.items() if v and k in keys}
     params = {k: v for k, v in obj.__dict__.items() if k.startswith("_") == False and k not in keys}
-    instance = session.query(obj.__class__).filter_by(**key_values)
-    if instance:
-      instance.update(params)
+    q = session_tmp.query(obj.__class__).filter_by(**key_values)
+    if q.count()==1:
+      q.update(params)
+      self.commit(session_tmp)
     else:
       session.add(obj)
     return session
